#ifndef _POVMESH_H
#define _POVMESH_H

#include <QTextStream>

#include <list>

template <class T> class Vector3d
{
	public:
		Vector3d(T t1, T t2, T t3) : X(t1), Y(t2), Z(t3) {}
		const T& x() const {return X;}
		const T& y() const {return Y;}
		const T& z() const {return Z;}
		
		T& x() {return X;}
		T& y() {return Y;}
		T& z() {return Z;}

                QTextStream& toQTextStream(QTextStream & ts) const {ts << "<" << X << ", " << Y << ", " << Z << ">"; return ts;}
                //friend QTextStream& operator<<(QTextStream & ts, Vector3d<T>& v);
	private:
		T X;
		T Y;
		T Z;
};



class POVMesh2
{
public:
	typedef Vector3d <double> dvector3d;
	typedef Vector3d <unsigned int> ivector3d;

	typedef std::list <dvector3d> PointListT;
	typedef std::list <ivector3d> FacesListT;

	POVMesh2() {};

	void addVertice(double x, double y, double z) {Vertices.push_back(dvector3d(x,y,z));}
	void addFace(unsigned int v1, unsigned int v2, unsigned int v3) {Faces.push_back(ivector3d(v1,v2,v3));}

        friend QTextStream &operator<<(QTextStream & ts, POVMesh2& m);
private:
	PointListT Vertices;
	FacesListT Faces;
};



#endif
